@@ -2,8 +2,9 @@
 PyVEX provides an interface that translates binary code into the VEX intermediate represenation (IR).
 For an introduction to VEX, take a look here: https://docs.angr.io/advanced-topics/ir
 """
+from typing import NewType, Any
 
-__version__ = (8, 20, 1, 7)
+__version__ = (8, 20, 7, 6)
 
 if bytes is str:
     raise Exception("This module is designed for python 3 only. Please install an older version to use python 2.")
@@ -12,11 +13,9 @@ import os
 import sys
 import cffi
 import pkg_resources
-
 from .vex_ffi import ffi_str as _ffi_str
 ffi = cffi.FFI()
 
-
 import logging
 logging.getLogger("pyvex").addHandler(logging.NullHandler())
 
@@ -35,12 +34,13 @@ def _find_c_lib():
     ffi.cdef(_ffi_str)
     # RTLD_GLOBAL used for sim_unicorn.so
     lib = ffi.dlopen(pyvex_path)
-    lib.vex_init()
+    if not lib.vex_init():
+        raise ImportError("libvex failed to initialize")
     # this looks up all the definitions (wtf)
     dir(lib)
     return lib
 
-pvc = _find_c_lib()
+pvc = _find_c_lib() # type: Any # This should be properly typed, but this seems non trivial
 
 # pylint: disable=wildcard-import
 from .enums import *
