@@ -1,6 +1,10 @@
 import copy
 import sys
 import itertools
+from typing import List, Optional
+
+from pyvex.expr import IRExpr
+from pyvex.stmt import IRStmt
 
 from . import VEXObject
 from . import expr, stmt
@@ -46,7 +50,7 @@ class IRSB(VEXObject):
 
     def __init__(self, data, mem_addr, arch, max_inst=None, max_bytes=None,
                  bytes_offset=0, traceflags=0, opt_level=1, num_inst=None, num_bytes=None, strict_block_end=False,
-                 skip_stmts=False, collect_data_refs=False):
+                 skip_stmts=False, collect_data_refs=False, cross_insn_opt=True):
         """
         :param data:                The bytes to lift. Can be either a string of bytes or a cffi buffer object.
                                     You may also pass None to initialize an empty IRSB.
@@ -83,10 +87,10 @@ class IRSB(VEXObject):
         self.addr = mem_addr
         self.arch = arch
 
-        self.statements = []
-        self.next = None
+        self.statements = [] # type: List[IRStmt]
+        self.next = None # type: Optional[IRExpr]
         self._tyenv = None
-        self.jumpkind = None
+        self.jumpkind = None # type: Optional[str]
         self._direct_next = None
         self._size = None
         self._instructions = None
@@ -108,6 +112,7 @@ class IRSB(VEXObject):
                         strict_block_end=strict_block_end,
                         skip_stmts=skip_stmts,
                         collect_data_refs=collect_data_refs,
+                        cross_insn_opt=cross_insn_opt,
                         )
             self._from_py(irsb)
 
